@@ -3,17 +3,11 @@ use parol::analysis::non_productive_non_terminals;
 use parol::obtain_grammar_config;
 
 pub fn main(args: &[&str]) -> Result<()> {
-    // Logger already initialized
-    // env_logger::init();
-    // $env:RUST_LOG="parol,parol_runtime=off,productivity=debug"
-    // debug!("env logger started");
-
     if args.len() < 2 {
         println!("Missing arguments <par-file>!");
         println!(
             "Example:\n\
-            cargo run --bin {} ./src/parser/parol-grammar-exp.par",
-            module_path!()
+            cargo run --bin parol productivity ./src/parser/parol-grammar-exp.par"
         );
     } else {
         let file_name = args[1].to_owned();
